:
#
# version 3.0 Sep 25 11:21:02 PDT 1998

umask 022
# This tool suite was written by and is copyrighted by Brad Powell, Matt 
# Archibald, and Dan Farmer 1992, 1993, 1994, 1995, 1996, 1997, 1998 with input 
# from Casper Dik, and Alec Muffett.
#
# The copyright holder disclaims all responsibility or liability with 
# respect to its usage or its effect upon hardware or computer 
# systems, and maintains copyright as set out in the "LICENSE" 
# document which accompanies distribution. 

# setup
TITANHOME=`pwd`
PATH=/usr/ucb:/bin:/usr/bin:/sbin:$TITANHOME/lib
MYNAME=`basename $0`

OS=`uname -r`
HOST=`uname -n`

# did things work out or not?
action=`sanity_check $MYNAME $1`
if test $? -ne 0 ; then
        exit 1
        fi

#
# suck in some lib functions (t_echo, etc.)
#
. misc_functions.sh

Intro() {

cat << EOF

 This program looks at /var/spool/cron/crontabs/root and changes 
 the directory permissions to be owned by root and non-writable
 by group or other. Then chown the files run by roots cron to
 be owned by root. Lastly it creates a /etc/cron.d/cron.allow
 and /etc/cron.d/at.allow and adds the user root to the file. 

EOF

}

FixCron() {

# Default chown/chmod stuff
# chown  root dirs and executables
# chmod 755 dirs and executables
# LIST= should be an awk script eventually to parse the contents of 
#       /var/spool/cron/crontabs/root and create  $LIST.
#

IFS=:
LIST=/etc:/etc/cron.d:/usr:/usr/sbin:/usr/lib:/usr/lib/fs:/usr/lib/fs/nfs:/usr/bin:/etc/cron.d/logchecker:/usr/lib/newsyslog:/usr/lib/fs/nfs/nsfind:/usr/bin/rdate:/usr/sbin/rtc 

#
# For any directories in the list check permissions
#

    for DIR in $LIST
      do
       if test -d $DIR
        then
	# Directories should always be owned by root if root cron executes it
	chown root $DIR
         if ls -dl $DIR | grep -s "^........w"
          then
           t_echo 0 "       $DIR is writeable by world; fixing."
           chmod o-w .
         fi

         if ls -dl . | grep -s "^.....w"
          then
           t_echo 0 "       $DIR is writeable by group; fixing"
           chmod g-w .
	 fi
          else
         t_echo 2 "    "  $DIR is not a directory.
        fi
    done
t_echo 2 "    "

#
# Now parse the files list
#
  for FILE in $LIST
  do
    if test -f $FILE
     then
      t_echo 0 "    " $FILE ownership being changed to root 
      chown root $FILE
    fi
  done

#
# Build cron.allow if it does not exist in this section
#
t_echo 2 "    "

  if [ -f /etc/cron.d/cron.allow ]; then
   t_echo 2 " /etc/cron.d/cron.allow already exists; moving it aside"
   /bin/mv /etc/cron.d/cron.allow /etc/cron.d/cron.allow.ORIG

    if [ $? -ne 0 ]; then
     t_echo 1
     t_echo 1 " Could not rename cron.allow; exiting"
     exit 1
    fi
  fi

if [  ! -f /etc/cron.d/cron.allow ]; then
t_echo 0 " Creating /etc/cron.d/cron.allow with root as the only user"
/bin/cat << EOF > /etc/cron.d/cron.allow
root
EOF
/bin/chmod 644 /etc/cron.d/cron.allow
fi

#
# Build at.allow if it does not exist in this section
#

t_echo 2 "    "

 if [ -f /etc/cron.d/at.allow ]; then
  t_echo 2 " /etc/cron.d/at.allow already exists; moving it aside"
  /bin/mv /etc/cron.d/at.allow /etc/cron.d/at.allow.ORIG
  if [ $? -ne 0 ]; then
   t_echo 2
   t_echo 1 " Could not rename at.allow; exiting"
   exit 1
  fi
 fi
 
if [  ! -f /etc/cron.d/at.allow ]; then
t_echo 0 " Creating /etc/cron.d/at.allow with root as the only user"
/bin/cat << EOF > /etc/cron.d/at.allow
root
EOF
/bin/chmod 644 /etc/cron.d/at.allow
fi

} 


CheckCron() {

# Default chown/chmod stuff
# chown  root dirs and executables
# chmod 755 dirs and executables
# LIST= should be an awk script eventually to parse the contents of 
#       /var/spool/cron/crontabs/root and create  $LIST.
#

IFS=:
LIST=/etc:/etc/cron.d:/usr:/usr/sbin:/usr/lib:/usr/lib/fs:/usr/lib/fs/nfs:/usr/bin:/etc/cron.d/logchecker:/usr/lib/newsyslog:/usr/lib/fs/nfs/nsfind:/usr/bin/rdate:/usr/sbin/rtc 

#
# For any directories in the list check permissions
#

    for DIR in $LIST
      do
       if test -d $DIR
        then
         if ls -dl $DIR | grep -s "^........w"
          then
           t_echo 0 "       $DIR is writeable by world - FAILS CHECK"
          else
           t_echo 2 "       $DIR is not writable by world - PASSES CHECK."
         fi

         if ls -dl $DIR | grep -s "^.....w"
          then
           t_echo 0 "       $DIR is writeable by group - FAILS CHECK"
          else
           t_echo 2 "       $DIR is not writeable by group - PASSES CHECK."
         fi
        fi
    done
t_echo 2 "    "

#
# Now parse the files list
#
  for FILE in $LIST
  do
    if test -f $FILE
     then
      t_echo 0 "    $FILE ownership should be changed to root "
    fi
  done

#
# Check for cron.allow containing only root in this section
#
t_echo 2 "    "

  if [ -f /etc/cron.d/cron.allow ]; then
    t_echo 2 " Checking contents of cron.allow..."
      RT=`grep root /etc/cron.d/cron.allow`
       if [ -z "$RT" ]; then
  t_echo 2 " cron.allow exists but does not contain root"
	if [ `wc -l /etc/cron.d/cron.allow | awk '{print $1}'` -ne 0 ]; then
  t_echo 0 "         cron.allow exists and allows other than root execute - FAILS CHECK "
	fi
       else
 t_echo 2 "         cron.allow allows root only - PASSES CHECK"
       fi
     else
     t_echo 0 "         No cron.allow file - FAILS CHECK"
     break
    fi

#
# Check for at.allow containing root in this section
#

t_echo 2 "    "

  if [ -f /etc/cron.d/at.allow ]; then
    t_echo 2 " Checking contents of at.allow..."
      RT=`grep root /etc/cron.d/at.allow`  
        if [ -z "$RT" ]; then
         t_echo 0 "         at.allow exists but does not contain root"
        if [ `wc -l /etc/cron.d/at.allow | awk '{print $1}'` -ne 0 ]; then
         t_echo 0 "         at.allow exists and allows other than root execute - FAILS CHECK "
        fi
       else
 t_echo 2 "         at.allow allows root only - PASSES CHECK"
       fi
     else 
     t_echo 0 "        No at.allow file - FAILS CHECK"
     break
    fi   



} 

action=$1
if [ -f /var/spool/cron/crontabs/root ]
 then
    t_echo 2 " File /var/spool/cron/crontabs/root exists; continuing"
 else
    t_echo 1 " User root doesn't seem to have a cron entry; exiting"
    exit 1
fi
        case ${action} in
	-[Ii]*)
	Intro
	;;
         -[Ff]*)
        CheckCron
        FixCron
        ;;
        -[Vv]*)
        CheckCron
        ;;
        *)
        t_echo 1 "         ERROR:Invalid arg $action"
        t_echo 1 "         ERROR:Usage $MYNAME -[ivf] (I)ntro/(V)erify/(F)ix"
        t_echo 1 " "
        ;;
        esac

# finis
