#!/bin/sh -x
#:
#
# version 3.0 Sep 25 11:21:02 PDT 1998

umask 022
# This tool suite was written by and is copyrighted by Brad Powell, Matt 
# Archibald, and Dan Farmer 1992, 1993, 1994, 1995, 1996, 1997, 1998 with input 
# from Casper Dik, and Alec Muffett.
#
# The copyright holder disclaims all responsibility or liability with 
# respect to its usage or its effect upon hardware or computer 
# systems, and maintains copyright as set out in the "LICENSE" 
# document which accompanies distribution. 

# setup
TITANHOME=`pwd`
PATH=/bin:/usr/bin:/sbin:/usr/ucb:$TITANHOME/lib
MYNAME=`basename $0`
OS=`uname -r`
HOST=`uname -n`
DATE=`/bin/date +%H%M%S`
CWD=`pwd`

case $OS in
  5*)
   INET=/etc/inet/inetd.conf
  ;;
  4*)
   INET=/etc/inetd.conf
  ;;
 *)
   t_echo 1 "       No valid OS for $0" 
 exit 1
;;
esac

# did things work out or not?
action=`$TITANHOME/lib/sanity_check $MYNAME $1`
if test $? -ne 0 ; then
        exit 1
        fi


#
# suck in some lib functions (t_echo, etc.)
#
. misc_functions.sh

Intro() {

cat << EOF

	This program looks for a WWW (HTTP/HTTPS) server running
	locally and tries to validate permissions on any htaccess
	or other locally defined access control files.
	Other areas checked are DocumentRoot, ServerRoot permissions
	on any user account access control files eg; htaccess
 
	In fix mode (-f) changes will set all files/dirs to owner
	read/write/execute, group read/execute, other execute.

	Be sure your server will operate with these permissions
	setting BEFORE YOU RUN IN FIX MODE...
	
EOF

}

FixAccess() {

 if [ -f ${INET} -a -s ${INET} ]; then
  t_echo 2 " File $INET exists - Backing up to ${INET}.${DATE}"
  /bin/cp ${INET} ${INET}.${DATE}
 else
  t_echo 1 "        Could not locate ${INET} - Exiting.."
  exit 1
 fi

 t_echo 0 " Making changes to $INET to close all insecure/chatty services..."
 t_echo 0 " Note: Manually edit inetd if you use non-standard services."
 t_echo 2 " The original version is saved as ${INET}.${DATE}"

 for SERVC in $ChatList
  do
ed - $INET << EOEF 
g/^$SERVC/s/^$SERVC/\# $SERVC/g
.
w
q
EOEF
 done
 t_echo 2 " Changing to mode 644 ..."
 /bin/chmod 644 ${INET}

}


CheckAccess() {

if [ -z "$*" ]; then
t_echo 0 "No DocumentRoot variable in config files - FAILS CHECK"
exit 1
fi

#
# Generate a list of all htaccess and htgroup entries into 
# a file called webcheck.list in this local directory
#

if [ -r ${CWD}/../logs/webcheck.list ]; then
 mv -f ${CWD}/../logs/webcheck.list ${CWD}/../logs/webcheck.last
 t_echo 2 "Saved old ${CWD}/../logs/webcheck.list"
 t_echo 2 "to ${CWD}/../logs/webcheck.last"
 t_echo 2 " "
fi

t_echo 2 "Generating list of all htaccess/htgroup files. Placing findings into"
t_echo 2 "${CWD}/../logs/webcheck.list for review"
t_echo 2 " "
echo "File list : " >>${CWD}/../logs/webcheck.list
t_echo 2 "---------------------------------" >>${CWD}/../logs/webcheck.list

for DIR in $*
 do
 find ${DIR} -print | egrep '(htacc|htgr)' >>${CWD}/../logs/webcheck.list
done

t_echo 2 "---------------------------------" >>${CWD}/../logs/webcheck.list
t_echo 2 " "

for name in `find ${DIR} -print | egrep '(htacc|htgr)'`
 do
  t_echo 2 "---------------------------------" >>${CWD}/../logs/webcheck.list
  t_echo 2 "Contents of $name" >>${CWD}/../logs/webcheck.list
  t_echo 2 "Pages in this directory viewable by: " >>${CWD}/../logs/webcheck.list
  t_echo 2 "-------------------------------------    " >>${CWD}/../logs/webcheck.list
    cat $name >>${CWD}/../logs/webcheck.list
  t_echo 2 " " >>${CWD}/../logs/webcheck.list
  t_echo 2 "================================" >>${CWD}/../logs/webcheck.list
  t_echo 2 " " >>${CWD}/../logs/webcheck.list
done
#
#
	if [ -r ${DIR}/access.conf ]; then
	cat ${DIR}/access.conf >>${CWD}/../logs/webcheck.list
	t_echo 2 " "
        fi

	t_echo 2 "Done. Check entries in ${CWD}/../logs/webcheck.list"
	t_echo 2 " "

}

GetServInfo() {
 
DIRS=`ps -ef | awk '{print $8}' | grep "[Hh][Tt][Tt][Pp]" | sed -e 's/httpd$//' | sort -u` 

 if [ -z "$DIRS" ]; then
  t_echo 2 "No HTTP server daemons in process tables - PASSES CHECK"
  exit 0
 else

for DIR in $DIRS
 do 
  CONF=`find ${DIR} -name conf -print`
  CONFILES=`find ${DIR}/${CONF} -name "*.conf" -print`

  t_echo 2
  t_echo 2 "Found the following config files: "
  t_echo 2
  t_echo 2 ${CONFILES}
  t_echo 2

  DOCROOTS=`grep "^DocumentRoot" ${CONFILES} | awk '{print $2}' | sort -u`

  t_echo 2 Found Doc Roots  =  ${DOCROOTS}
done 

fi
 
}

action=$1
        case ${action} in
	-[Ii]*)
	Intro
	;;
         -[Ff]*)
	GetServInfo
        FixAccess ${DOCROOTS}
        ;;
        -[Vv]*)
	GetServInfo
        CheckAccess ${DOCROOTS}
        ;;
        *)
        t_echo 1 " ERROR - Invalid arg $action"
        t_echo 1 " ERROR - Usage $MYNAME -[ivf] (I)ntro/(V)erify/(F)ix"
        t_echo 1 " "
        ;;
        esac

